---
title: "Book Review: Square One"
date: 2016-12-31T15:18:16Z
tags: ["steve patterson","cartesian rationalism","metaphysics","reviews"]
topics: ["philosophy"]
image: img/square-one.jpg
draft: false
---

I discovered [Steve Patterson](https://www.youtube.com/channel/UCt5ur6JjrWaWAalL66Dt40A) by way of my YouTube recommendations some time in the late summer or fall of 2016. I’ve not yet listened to all of his back catalogue, but I have listened to a number of his great interviews and interview “breakdowns”. He recently self-published a short book called “[Square One: The Foundations of Knowledge](https://www.amazon.co.uk/Square-One-Foundations-Steve-Patterson-ebook/dp/B01M9JL27L/ref=sr_1_1?s=digital-text&ie=UTF8&qid=1483138431&sr=1-1&keywords=square+one+the+foundations+of+knowledge)”, via Amazon’s CreateSpace. I love epistemology and logic, and I’m keenly interested in the growing phenomenon of “internet philosophers” (many of whom proudly proclaim themselves emancipated from academia). So, this was a book I had to read.

The book is a relatively short read (even as a slow reader, it only took me about 6 hours to finish it, including taking notes), and I found it engaging, well structured, and passionately argued. For anyone interested in an overview in plain language of the traditional [Rationalist philosophical position](http://www.iep.utm.edu/cont-rat/), this book is an excellent first step for beginners. Though the book does leave many questions unanswered (I will highlight two of them in this review), it makes for a useful launchpad into further exploration. And as Patterson himself admits:

> Square One is the starting point, but it’s not the ending point.

### The Method of Doubt: A Manifesto

Patterson’s approach to knowledge and truth is similar to Descartes in his Meditations, challenging the reader to take a radically skeptical look at all of the assumptions and presuppositions underlying his “worldview” (the whole collection of beliefs about himself and the world around him), in the pursuit of “deeper” truth. Also like Descartes, Patterson’s ambition is to establish a [Foundationalist](http://www.iep.utm.edu/found-ep/) basis for all of his beliefs. But Patterson isn’t actually offering a defense of Cartesian Rationalism with this book. Rather, he is making a personal statement of commitment to it. [In his podcast, he says](https://www.youtube.com/watch?v=40Qyy-hG37g#t=3m10s) that the purpose of this book is to announce to the world that “*Truth is discoverable. I’m certain of it. It’s not popular to say. It’s not popular to think. But I know it’s true.*”. He doesn’t explain what “discoverable” means, but as I’ll show in a moment, he seems to take it to mean something similar to Descartes’ own “clear and distinct idea”, which lies somewhere between intuition and deduction.

He spends a good deal of effort decrying academic philosophers for rejecting the pursuit of truth and knowledge, and claims it’s become unfashionable nowadays to talk about such things in academic circles. Most of us on the internet who might interpret that as an obvious implicit attack on Post-Modernist relativism, would be wrong to think so. What Steve is actually objecting to, is the fact that most modern philosophers reject Descartes’ notions of “truth” and “knowledge”, as described in his Discourses and Meditations. Descartes’ notions require “absolute certainty”, which is to say, utterly impervious to mistake or error. This is the “truth” and “knowledge” that Patterson seeks as well, and (though I’ll save this for a later discussion) it entirely explains his own natural tendency toward dualism.

But there are much better reasons explaining why modern philosophy rejects Cartesian Rationalism, than that they simply don’t appreciate the value of truth or knowledge anymore. This seems to me, to be a highly uncharitable (and somewhat unfounded) view. For one thing, Descartes had a very specific project in mind, when he concocted his Method of Doubt. Namely, to find a way to demonstrate to himself by way way of *pure intuition* that God exists. He wanted to do this because he recognized consciously, that not only is sense perception unreliable at times, so is our capacity to reason deductively. And, for all his effort, Descartes was never really able to escape his *cogito* successfully. This is because, at every attempt, he needed to rely upon reasoning to do it (or, as he would have called it, “movements of thought” from intuition to deduction). There are reams and reams of undergraduate essays stretching back a couple hundred of years, explaining why this is the case. For what it’s worth, you can read my own take on the question, [here](http://philosophy.gmgauthier.com/the-importance-of-descartes-existence/).

Patterson himself explicitly rejects any attempt to justify his Rationalism beyond his [Russellian version](http://www.personal.kent.edu/~rmuhamma/Philosophy/RBwritings/ProbPhiloBook/chap-II.htm) of the *cogito*, opting instead to adopt an axiomatic stance:

> If we want to discover the truth, we shouldn’t waste time arguing at the surface level – about “whether or not I’m sitting on a chair.” We have to go deeper. We have to sort out whether our feelings correspond to an external world. We need to grapple with the possibility of hallucinations. After the foundations have been sorted, then perhaps the original question can be answered. Intuitively, it seems like “why?” questions can be asked without end – that ideas cannot stand alone without deeper reasons. But in fact, there are truths so foundational that the question “why?” does not apply. These truths are not contingent on other premises; they are necessary. In fact, these truths are so fundamental, that every other idea presupposes them. They rest at the bottom of every worldview, whether explicit or implicit. They are certain, absolute, and objective. Without them, one cannot even have coherent thoughts.

Then later, flatly admitting he simply wasn’t going to deal with the topic in this book:

> You’ll notice that I’ve smuggled in an assumption here – that indeed, the birds do exist separate of my conception of them. How do I know this? Well, I don’t know with certainty. It’s an assumption, and it’s a larger topic in the philosophy of language and metaphysics which is beyond the scope of this book. Things might exist outside of our minds, and the purpose of these examples was to illustrate the meaning of the term “exist,” not to make the case for a mind-independent reality.

But without an attempt to go beyond the *cogito* (as Patterson has constructed it), the pursuit of absolute certainty becomes nothing more than a meaningless academic puzzle. If the only thing I can be “certain” of, is that there is an awareness that calls itself “me”, and I can use this knowledge only to establish the rules by which that awareness seems to operate on the various objects within it, then there’s really nothing more to do. But the whole point of this kind of certainty, as Descartes argued, is to be able to make statements about the external world that are absolute, and unquestionable. To build a body of *indubitable knowledge* about the universe that is so well defended as to be impenetrable. Descartes says in Meditation 1 that he his ambition for the Method of Doubt is to establish a new “science”, and that is why he tries to create a bridge of certainty between his *cogito* and his physical extension into three-dimensional space. Patterson, alternatively, says he is attempting to establish the meaning of the term “exist”, but without a chain of *logical necessities* linking the birds “inside his mind” with the birds “outside his mind”, the term “exist” could only resolve to a solipsism. Descartes understood this problem, struggled mightily in the Meditations to escape it, and was ultimately unsuccessful.

I queried Steve on this, in the comments on one of his videos. This is what he had to say about it:

> **Me:** Are you planning on a follow-up book to cover the question this book teased? I’m super curious to see how you go from Russell’s ” awareness exists ” to ” the universe, external to this particular awareness, exists “, with absolute certainty. Poor Descartes fell all over himself in Meditation 3 and 4, trying to get there. So, I’m champing at the bit to see if it can be done better!﻿
>
> **Steve:** I cannot go to “an external universe exists with certainty.” I can go to, “the theory of an external world is the most compelling explanation for my experiences,” which is satisfactory for me. I can imagine, at some future date, coming to realize that everything exists in my mind (unlikely, but logically possible). Therefore, I cannot be certain it won’t happen.

But this is precisely why modern philosophy no longer accepts Descartes standard of absolute certainty as a defining feature of knowledge or truth. All we can know, is what is in our own minds. So, if we want to move forward and grow, we have to accept some degree of uncertainty and ambiguity in our understanding of the world. In other words, Descartes is the answer to that “Why?” question. The only question, now, is how much. Even Steve has more or less admitted that, here.

### Logic Exists Necessarily, But It Doesn’t Exist

Patterson devotes all of chapter three to his cornerstone: logic. But not all of logic. Only the basic Aristotelian conception of deductive logic. As an overview of Aristotle’s three laws, this chapter is magnificent. His explication of the excluded middle is one of the easiest to understand I’ve seen in print, in a philosophy text. But I have to admit, I found his explanation of what “logic is” in a fundamental sense, to be extremely confusing. He says in one part of the book, that it is *not* a “part” of existence, but in another part of the book says it is “a part of the fabric of everything in existence”, and “it is a part of every thing, even those things that are different”. He also insists that logic and existence are inseparable, because (by inference) logic is built-in to the identity of every object in the universe, by virtue of the fact that you cannot separate a thing from its identity. In fact, this is his Sartre-like mantra: “*Logic and Existence Are Inseparable*”. But in yet another part of the book, he defines logic as “the rules of existence”, which suggests that logic might simply be a mere description of the behavior of the universe, as we experience it, rather than some sort of metaphysical expression of universality or particularity.

Steve struggles mightily in this book to give logic – the laws themselves – some sort of ontological reality without having to concede outright metaphysical existence. Repeatedly, he insists they don’t exist, in the same way a book or a planet exist. But, as I have already explained, he can’t help but try to find a way to mingle them with actual existents, in some way. But it seems to me, there’s a much simpler explanation of what logic actually is. I will let [Samuel Guttenplan](https://www.amazon.co.uk/Languages-Logic-Introduction-Formal/dp/155786988X/ref=sr_1_1?s=digital-text&ie=UTF8&qid=1483223200&sr=8-1&keywords=guttenplan+languages+of+logic) explain it for me:

> Logic… is the study of certain specific features of thinking… One could characterize it as movements of thought… Logic could be seen as containing the laws of this sort of motion… The subject matter of logic… is precisely those movements of thought which are defensible [via justification]. Logic studies the transitions in our states of mind which we are prepared to defend as justifiable…

Interestingly, there is a second essential aspect to this definition, that Patterson seems to have missed in his own explication of the topic. Again, I’ll let Guttenplan explain:

> From what I have said so far, you might now have the impression that logic consists in the study of how human beings actually think – how they are successful, when they are, and why they go wrong, when they do. Seen this way, logic would be descriptive of human reasoning. Its goal would be to provide laws of motion for thoughts in somewhat the way that astronomers provide laws of motion for planets and stars… The laws are supposed to fit the motion of the planets; if they fail to do so, the defect is in the laws. Matters are very different with logic. The laws of logic… are intended to characterize arguments as “good” or “bad”… they are much more like moral laws than they are like physical laws. They set a standard or norm of what constitutes good reasoning and it is with respect to this norm that we can see our reasoning as sometimes faulty.

This sort of definition of logic might make Steve’s job a bit easier. Since he’s explicitly not interested in justifying a mind-independent reality to his own standard of absolute certainty, he need not search in vain for some ineffable ontological status for logic, independent of his own mind. He could simply argue that he is describing the way his mind works, and describing the normative rules against which he judges his own thoughts.

However, to be sure, Guttenplan is himself smuggling in a presupposed reality, in that these normative rules had to come from somewhere — and in fact, as Aristotle will tell you, they come from our common experience of objects in the physical world. Aristotle was using the “Laws” in both the descriptive and the normative sense, to describe the behavior of things, and to prescribe processes of thought that conformed to those observations. But Guttenplan isn’t defending Cartesian Rationalism, so he has no burden to bear in this respect. A presumed reality is granted to him by default.

But this is Patterson’s challenge. Either he abandons certainty as a standard of knowledge for himself in order to accept knowledge of an external world on contingent grounds (in which case, he’s not really a Rationalist), or he abandons any claim to knowledge of a reality external to his mind in order to maintain his standard of certainty. And that means he can’t rely upon deduction either, since the laws of logic are a description of a mind-independent reality that we use to judge our thinking. Alternatively, he might eventually discover some “third way”, in which certainty can be established in spite of the corrigibility of our senses and our reasoning skills.

### Final Thoughts

I want to say, in conclusion, that despite these flaws, I really enjoyed reading this book. I greatly admire people willing to do this kind of work, precisely because it necessarily comes with criticism, which can often feel like walking directly into an ice-pellet storm. Patterson’s passion in this text was absolutely palpable, and left me envying him in spite of his Cartesianism.



```[Imported from exitingthecave.com on 28 November 2021]```

