---
title: "Facts, Values, Rights, and Human Beings"
date: 2020-06-22T21:28:16Z
tags: ["ethics","metaphysics","moral-psychology","rights","self-knowledge","animal rationality"]
topics: ["philosophy","politics"]
image: img/jane-goodall.jpg
draft: false
---

The human animal is thought by some to have a “divine spark” in him. What is this? I don’t mean in a metaphysical or definitional sense. I mean, what do humans do, what capacity do they have, what power are they endowed with, that sets them apart from the other animals so much so that they are thought to have this spark? Why on earth would anyone say humans are “touched by the divine”?

You can see hints of what this might be, in the story of Genesis. Not that God made Adam. But that God gave Adam the *task of naming all of the animals*, and later, that Adam and Eve took for themselves the *knowledge of good and evil*. But I’m getting ahead of myself.

When you look at other animals – the dolphin, or the chimpanzee, or the bear, or the dog, for example – you can see a great deal of cognitive functionality in its behavior. It knows what it desires, it knows how to maneuver around in its environment, and it has the calculative capacity to figure out how to manipulate that environment (to the extent that its body will allow) to get at what it desires. Sometimes it fails, but more often than not, it succeeds (otherwise, by natural selection, it would have perished as a species). Mankind has these abilities, too. In fact, they are orders of magnitude more sophisticated than any of the other animals. Mankind has so refined his knowledge of his surroundings, and how to manipulate those surroundings, that there is almost nothing among his array of infinite desires, that he cannot achieve, including traveling to other planets, to start the process all over again.

But this is only a difference in degree from the other animals (albeit, vast); only weakly warranting an accolade like “divinity”. There is one capacity man has, however, that the rest do not have. As I said, the dog is smart enough to know what it wants, and smart enough to figure out ways to get what it wants. Just look at any well adjusted pet, and his ability to manipulate his master, to see what I mean. But there is one thing Rover cannot do, that his master can. Rover cannot look at the shmorgasbord of his own desires and ask himself, “Are these the right desires? Why do I yearn for the things that I do? Should I yearn for something different?” In short, Rover has no conscience.

This is why Socrates made such an obsession out of the Delphic Oracle’s famous edict to “know thyself”. Many of his contemporaries were busy staring at the stars, or scrabbling in the dirt for the smallest thing they could find, or speculating about the true nature of water, or fire. But Socrates realized that the most perplexing question in the whole universe, was man’s own self-conscious moral ego. Why did he have one? How did we know that it was telling us the truth or not? Where did it come from? How do we exercise it properly (a meta-moral question, in itself)?

To be fair to Rover, he certainly has many emotions we would call “moral emotions”. He gets angry when his pack mates are threatened. He gets sad when his pack mates are hurt or die. He cowers when the pack leader chastises him. He jostles, challenges, and manipulates other pack mates, for a chance at the leadership position, and displays confidence when he earns it. I do not think that it is purely anthropomorphism to recognize these for what they are. But these are only rudiments. Building blocks. A loose assemblage of some of the *necessary components* of a moral conscience, not sufficient in themselves. Frans de Waal recognized this in his work on primates, and wrote about it in his books, “Our Inner Ape”, and “Primates and Philosophers”.

It is the joining of a sufficient degree of cognitive capacity with a sufficient amount of practical reasoning, and the coupling of both of those things to conscious self and other unique among primates, that has given rise to the capacity to question desires and interrogate emotions, and to alter behaviors based on those inquiries. This is what our “divine spark” is. It is our moral sensibility; our conscience. It is this conscience that is both our gift, and our curse. And that is why the story of Eden is so compelling to us.

This capacity for moral self-inspection also gives us a special capacity that animals do not have. The capacity to *value*. Animals certainly desire things, as we do. But lacking the capacity for self-inspection, and the reasoning needed to engage in that activity, they cannot *value* what they desire. They are more-or-less “hard wired” to desire the things that are necessary to their own survival, in the environment within which they arose as a species. Some species are more adaptable to other environments than others, but that is somewhat beside the point here. Which is, that no animal, no matter how adaptable, can *choose what to desire*. We can, and when we do, we create something called a “value”. Those things that we consciously choose to desire, are those things that we value, because in order to determine which desires to satisfy, and which desires to deny, we must *evaluate them*.

The question of how we discover a standard by which we can effectively evaluate the various desires, is the responsibility of the discipline of moral philosophy. It is beyond the scope of these remarks to examine the various theories, except to say that it is this question that rests at the heart of *every other human question we can ask*. Now, moral psychologists like Jonathan Haidt will tell you that this inquiry ultimately just comes to (in metaphorical terms) the bony little Indian boy of reason, eventually finding the right levers with which to manipulate the elephant of emotional baggage. Maturation, for them, is simply becoming aware of how the preset knobs on your panel of sensibilities is set, and acting accordingly. But this is only half the picture. While it is true that we are born with “presets”, and that pressures in the environment can alter them, it is also true that with practice, *we can alter our own presets*. In fact, we can add or subtract from the array of knobs available. Haidt and others think there is a fixed set of dials, over which we have little control. This is a mistake. And it is this sort of deterministic thinking that leads to the kind of suffering we are experiencing as a civilization.

In any case, returning from that digression, the point here is the *creation of value* that occurs in the process of evaluating and choosing desires. This is perhaps the one fundamental idea for which Ayn Rand deserves at least some credit. This is not quite the same thing as what Nietzsche and Sartre were arguing for. Theirs is an arbitrary selection, anchored in the submission to desire itself. To put it in Haidt’s metaphor, it would be like the rider just choosing to prefer wherever the elephant happens to go, because it’s easier than trying to manipulate the elephant. This is not at all what is meant by the creation of value in evaluation. But here’s where Rand would have parted company with me. That creation is a *metaphysical* reality. Not a physical one. The relationship we are dealing with here, is between three separate parties: the desire, the world, and *the conscience*. The animal appetite desires something in the world, the conscience stands between them, and arbitrates the relationship. That arbitration does not discover values (as Rand would have said), it *creates* them. Without the conscience, in otherwords, there is no value. There is only desire, satisfied or denied.

Animals have a limited range of possible desires. They are more-or-less programmed into them, and meant to meet the basic needs of survival for the animal. This is because they have no self-conscious ego, and no imagination. But, because man is equipped with an imagination and the cognitive capacity to realize his imagination, his desires are infinite because his reality is infinite (in a practical sense, if not in principle). The conscience, then, is the mechanism by which we narrow the choices down to a finite set of achievable ends, relative to a time preference. And, in that selection process, create the list of things that are *valuable*.

This is interesting, because it suggests a reason why centering moral worth in the capacity to reason is, while not quite sufficient, pointing in the right direction. It explains why doing so is not simply planting a flag in a matter of fact about human beings and declaring “here, be moral worth!”. This capacity for moral self-evaluation of our desires by way of our cognition is *categorically different* from, say, the capacity to run fast or the capacity to play the piano, or even the capacity to start a fire, because it is the union of *fact* and *value*. It is the bridge between what is, and what matters.

If we’re not careful, however, it would be easy to jump immediately from this, to some form of subjectivist relativism, or Randian egoism. But, as I said, this is neither Nietzshean existentialism, nor Randian egoism. There is more to this part of the story than I have space for here. It will have to wait for another day.

The point of this entire trek, is that what we have in this, at a minimum, is a basis for Lockean self-ownership that need not rely explicitly on biblical exegesis for its justification. And, from there, a firm foundation for political rights. Though I am sympathetic to Locke, because I find myself unable to dismiss the God hypothesis as easily as some others, I think that a political system like the American one needs a secular grounding, because it cannot take for granted the religious presuppositions Locke relied upon to get to self-ownership. If we are to conscript agreement in the fundamental dignity of man and the “natural” rights that flow from that, from a population of pluralistic individualists, then we cannot take anything for granted, really. The justification must begin from as few assumptions as possible. This exploration offers at least one possible approach to solving that problem.
