---
title: "Plato, Parmenides, and the Theory of Forms - Part 2"
date: 2018-09-08T21:58:21Z
tags: ["platonism","dualism","eidos","forms","idealism","realism"]
topics: ["philosophy"]
image: img/panpsychic.jpg
draft: false
---

In this installment of the series on Plato’s Forms, we’ll have a brief look at the major conceptions of the theory, some of the key differences, and dig deep into the one formulation Plato seems to have favored the most. For those of you looking for a thorough discussion of Parmenides’ refutations, you’ll have to wait until the last installment. In keeping with the principle of the first post, the idea here is to just try to understand the theory itself, and the problem it was trying to solve, before we make any move to object to it.

In any case, the theory of Forms comes in three basic varieties, and these varieties are themselves the expression of a tension between two different characterizations of the forms – immanence versus transcendence (which was touched on briefly in the first post). This tension expresses itself further, in a conflict over how we relate to the forms. To put it in simple terms, how “separate” are we, from the Forms? Each of the variations of the theory attempts to reconcile these two conflicts in very different ways. I will present the three varieties here, in the order of strenuousness with which Plato argued for them, weakest to strongest.

### Forms as literal ideas

> …maybe each of the forms is a thought, and properly occurs only in the mind. In this way each of them might be one and no longer face the difficulty [ of infinite regress and multitude ]… each thought is one, is a thought of something that is ‘one thing’, which the thought thinks is over all the instances, being some one [common] character…” Parmenides, 132b-c

This is the weakest of the formulations, and the least strenuously argued for. What’s fascinating, is that it is the most intuitive of the definitions, is what most people imagine at first, when the discussion of Plato’s forms begins, and from a modern perspective, offers the closest conception to modern mathematical concepts like ‘number’ and ‘formula’.

As we’ll see later, this formulation is not entirely incongruous with the others. Plato’s theory of knowledge as recollection requires that the recollection reside somewhere, and in the mind is where that is. But what makes this theory different from the others, is that it attempts to claim that the form is *only* in the mind, and nowhere else (recollected or otherwise).

Given Socrates’ emphasis on the method of definition in his early dialogues, it may be tempting to think of the Forms merely as “definitions of things” (as the attempt to capture in language, the one or two properties of a thing, that makes it *that thing*), and in this sense, the theory of Forms as Ideas has some plausibility. But, as G.M.A. Grube points out:

> “for a definition to be universally valid, [Plato] felt it must be the definition of a constant reality, independent of any particular specimen of the thing defined. A definition of Man [for example] is not of any particular man, but of *Man*, which is a reality quite independent of the particular *you* or *me*… This reality is the ‘Eidos’, the Platonic Form of Man.” (pg. 4)

In the next post, we’ll discuss Parmenides’ objections, showing how Forms as merely ideas could not be the case, but the point here, is to say that because Plato is quietly already committed to a different formulation (the noumenal one discussed below), he is quick to abandon this one, on Parmenides’ first refutation of it.

### Forms as the patterns of the artificer

> “What appears most likely to me is this: these forms are like patterns set in nature, and other things resemble them and are likenesses; and this partaking of the Forms is, for the other things, simply being modeled on them…” Parmenides, 132d

Here, Plato envisions the Forms as either a sculptor’s miniature, or as a blacksmith’s mold. This formulation of the Forms is one Aristotle would likely have found appealing. It suggests a shapeless, indefinite substance which is “pressed” or “sculpted” into a definite object, according to a plan or model, like a statue, or a coin, or a sword.

This notion of the Forms is appealing as an ontological explanation of the existence of things (clearly, similar concepts were appealing to Aristotle in the same way). But Plato’s task with the Forms was not accounting for the existence of things. It was to account for the *knowledge* of the things that exist. More to the point, accounting for our subjective experience of those things. Why do we have the idea of ‘things’ at all? Again, Parmenides will make short work of this conception of the Forms, as well, and Plato will move on.

### Forms as noumenal entities

I am borrowing the term from Kant, here, because I think it best (and most concisely) expresses the notion of Forms, as Plato seems to have finally settled on them: ideal objects belonging to a transcendental reality, apprehended only by the mind itself.

There are many places where Plato makes this argument. The most famous is perhaps the depiction of The Good in The Republic, but the best technical explanations can be found right in the Parmenides, along with several passages in the Phaedo, and the Meno.

This passage from the Phaedo best encapsulates the problem that Plato is trying to solve, and begins to introduce us to the kind of thing a Form might be:

> “…mathematical reasoning is most successful when the mind is not troubled by hearing, sight, pleasure, pain, or any of those things; when it is alone as far as possible and **without concern for the body**; when it has the least possible contact or association with the body it reaches out **toward reality**… whoever of us prepares himself best and most exactly to perceive each **thing in itself** will come nearest to **knowing** each thing…” Phaedo, 65b (emphases added by me)

It is not so hard to see why Whitehead famously declared that all of the European philosophical tradition could be safely characterized as “footnotes to Plato”. This passage hints strongly not only at Kantian noumenal “things in themselves”, but also at Cartesian “clear and distinct ideas”. In its emphasis on mathematics, and the absolute necessity of intelligibility for “true” knowledge, Plato has presaged (or, more probably, provided the intellectual fodder for) the Rationalist move, and mind-body dualism, by almost two thousand years.

In any case, the point is that Plato wants to understand how the world we live in – the world of constant “flux” (as Heraclitus would put it) – can be *intelligible at all*. Why aren’t humans just like the other animals, who are capable of nothing more than generation, sensible excitation, and destruction? How is it that we can also *understand* our plight as mortal creatures? For that, as he says in the Phaedo passage above, we must contemplate the underlying reality of things, and when we do, what we will find, is a reality composed fundamentally of intelligible things that give the superficial sensible reality, its definite presence:

> “…there are certain Forms from which [particular things], by getting a share of them, derive their names — as, for instance, they come to be *like* by getting a share of Likeness, *large* by getting a share of Largeness, and *just* and *beautiful* by getting a share of Justice and Beauty…” Parmenides, 131a

and:

> “…if, in the case of sticks and stones and such things, someone tries to show that the same thing is many and one, we say that he is demonstrating **something** to be many and one, not **the one** to be many, or **the many** one…” Parmenides, 129a

and:

> “[The Form would not be] at the same time, as a whole, in things that are many and separate; and thus… separate from itself… [because, like the day], the Form is in many places at the same time and is nonetheless not separate from itself…” Parmenides, 131b

and:

> “…there is an absolute beauty and goodness and largeness and the like… if there be anything beautiful other than absolute beauty (should there be such), that it can be beautiful only insofar as it partakes of absolute Beauty – and I should say the same of everything…” Phaedo, 100b

and:

> “….nothing makes a thing beautiful but the presence and participation in Beauty in whatever way or manner obtained; for as to the manner I am uncertain, but I am certain – I stoutly contend – that by Beauty all beautiful things become beautiful…” Phaedo, 102b

and:

> “Socrates: …what do you call the quality by which [the bees] do not differ, but are alike? You could find me an answer, I presume?
>
> Meno: I could
>
> Socrates: And likewise, with the virtues, however many and varied they may be, they all have **one common character** whereby they are virtues, and on which one could of course be wise and keep an eye when one is **giving a definitive answer** to what virtue **really is**…” Meno, 72b-c (emphases are mine)

The idea of a “Form”, then, seems to be serving a number of useful purposes. It is an attempt to give definitive account for difficult to define objects, such as “man” and “animal”; it is an attempt to “quantify” the qualitative aspects of reality, such as “the beautiful”, and “the virtuous” (even including subjective experiences such as “largeness” and “sameness”); and it is an attempt to explain how these things are not mere *doxa* (opinion), but *noesis* (knowledge). That’s quite a tall order. As we’ll see in the upcoming conclusion, Plato wasn’t as successful at accomplishing these goals, as he might have assumed he was. But there is a very good reason for this, I think.

### The plausibility of Forms

Why was Plato so enamored with the notion of the Form? We will see in the subsequent conclusion, that from his Parmenides, he must have been entirely aware of the weaknesses of this theory. Grube says,

> “Plato insisted upon the possibility of knowledge, and upon the existence of absolute values. To do this, he had to establish the existence of an objective, universally valid reality, and this he found in his Forms…” Grube, Pg. 3

But why was he insisting on “absolutes” at all? This goes back to an earlier question I posed: why is it that we are able to look upon the world as sensible beings, and yet apprehend it as intelligible beings? How is it that the world has an intelligible order, and how is it that we are able to apprehend it? Two key influences on Plato (according to some scholars) were Pythagoras, and Anaxagoras. The former impressed upon Plato, the fact that there were indeed *knowable realities* that stood independent of our senses. Mathematics *works*, and it works everywhere and always, regardless of how the physical world may be changing continuously. This is why the Forms must be universal and unchanging, for Plato. Our *qualitative experience* of the world must be explainable in just the same way as our *quantitative understanding* of it.

More importantly, however, is what Plato took from Anaxagoras. As Grube rightly points out:

> “…[Anaxagoras] insisted on the permanence of qualities, and posited **Nous** [mind] as the origin of motion and the **guiding principle** of the universe… the essential reality of things was to be found not in the material components but in their **Logos** …we can give them credit for having build on the solid fact that all physics, if not all science, has a mathematical basis…,” Grube, pg. 2

Logos, then, is the discernibility or intelligibility of the universe; intelligibility is only possible where Nous is present; Nous is the guiding principle and motivating force of all things, according to Anaxagoras. To understand the universe, then, is to understand the mind that gives rise to it. What is this mind? What is its nature? How different is it from the mind of man? Is it Plato’s Demiurge? Does it have conscious intention as we do? Is the universe itself a kind of medium within which mind is made manifest (like writing on paper, or a bacterial culture in agar)?

This is why the Forms are important, and why Plato saw them as essential. He imagined them to be not only the way we made contact with the mind of God, but also the way in which the human mind exercised its “god resembling powers”. This is the reason why Aristotle argued for the contemplative life as the highest form of virtuous living, and imagined the Demiurge as a being that lived a perpetual life of self-contemplation. The reality that mattered, was the *transcendent* reality, where the mind that instantiated the order we were capable of discerning existed, and it should be our goal as humans to return to that reality and give an account of our mortality.

This is also why the idea of the Form as an “immanent” character is a non-starter, ultimately, for Plato: because it doesn’t actually answer the question he’s asking. Insisting on “immanent” character, is just to push back the goal posts. Why is it we are capable of recognizing “immanent” order? By apprehending the transcendent order that gives rise to it in the first place.

As we’ll see in the final installment of this series, the insistence on transcendence is going to be a major problem for Plato. This is the problem of “separation”, I mentioned earlier. Parmenides makes the problem of our relation to the Forms a centerpiece of his criticism, and it is a criticism from which Plato did not seem to recover.

Stay tuned for part three….

```[imported from exitingthecave.com on 30 November 2021]```

