---
title: "Ruminations on Justice in Plato and Aristotle"
date: 2021-01-30T16:34:35Z
tags: ["justice","greek philosophy"]
topics: ["philosophy"]
image: img/plato-and-aristotle.jpg
draft: false
---

The following is not a sustained argument, so much as an exploration of impressions derived from the last few years of reading. There are arguments to be gleaned from it, but I must confess, they’re not entirely conscious efforts. The blind squirrel of my mind is finding a few nuts as he tries to feel his way out of the forest.

Plato and Aristotle had very *different ideas* about Justice. But I am less and less convinced that they *disagreed* about it, fundamentally. This is true for most of the systematic philosophy (as much as it can be so called, for Plato), from their metaphysics to their ethics and politics. It’s not really difficult to see why. Aristotle was a trained Platonist, after all. And both Plato and Aristotle were responding to the challenge laid down by Parmenides. Namely, that plurality could only be an illusion if unity could be proved, and as far as Parmenides was concerned, it was proved. Likewise, a world of becoming must also be an illusion if being could be conclusively demonstrated — and as far as Parmenides was concerned, that was also proved.

It has been suggested by some authors, that Plato represents the culmination of a Hegelian dialectic, in which Heraclitus represents the thesis (the assertion that the only thing that is real is change), Parmenides the antithesis (the assertion that the only thing that is real is the unchanging), and Plato the synthesis (turns out they’re both right, except the unchanging is more real than the changing). I don’t think this is quite right. There is no synthetic terminus. Ideas and thinkers feed off each other, in a continuous dance. There is no point at which inquiry ceases with a final perfect synthesis. What’s more, Plato and Aristotle were attempting to resolve a paradox, not simply stating theses in reaction to their predecessor’s theses. They were participating in the conveyance of ideas into the future, and that necessarily comes with both accretions and reductions.

But what does this have to do with Justice? Well, if you think that there is not merely an order to the universe to be discerned by man, but a *correct* order, that must be understood to be obeyed (in the sense of conformity to what is best, not in the sense of submission to a rule), then justice becomes a highly relevant topic. Indeed, it is elevated to the level of a cornerstone concept in the organization of any good society. Plato and Aristotle were *systematic* thinkers. This means, they tried to build a complete philosophy in which every part coherently fits into every other part. Thus, justice must make *metaphysical* sense, as much as it does moral and political sense. For both Plato and Aristotle, that means reconciling both their metaphysical, and their moral and political notions, with the challenge of Parmenides.

### Ideas and Methodologies

For Aristotle, justice is many things, not one. As is his habit, he insists that these kinds of justice cannot be reduced, but are exemplars of separate categories of being. Those categories can, however, be understood as consisting in three relations: between fellow men, between man and his nature, and between man and his polis. Justice in each category is a proportionate desert, measured according to The Good, determined by man’s nature, derived from his substantive being, and known by reasoning from observation of that nature.

For Plato, justice is the rightly ordered soul, which is patterned after the rightly ordered state, which is ordered according to the Form of Justice, which is derived from the Form of the Absolute Good in which reason is supreme because of its affinity with The One,which unifies all things according to itself, and can be known by man by way of dialectic recollection via reason.

How are these two understandings of Justice arrived at? How can they be such different ideas of Justice, and yet still agree? I think the inquiry into these questions begins with examining the methodologies of the two men. More specifically, how does each philosopher

Plato’s idea of knowledge of Ideas — not its acquisition, but what it is itself — is analogous to our knowledge of numbers. They do not enter our minds on instruction, but are already present at birth. They are merely buried by the fog of material existence, and must be uncovered. This uncovering process is the acquisition of knowledge. It begins with a postulate or formula describing the idea, which is then scrutinized by way of a form of dialectic known as ‘elenchus’. This process chisels away at falsehoods clinging to the concept or hidden within it. Whatever remains is the truth, and your recollection of The Form is successful.

Plato’s Ideas (or Forms), then, are like mathematical postulates in that they are “a priori” or “analytical”, which is to say they begin and end in the mind. External exemplars of them are only accidental to their essential meaning. For example, I need not have apples on hand if I want to sum or subtract individuals, or roll a ball down an incline plane if I want to calculate acceleration, but these instances can be helpful for illustrating the truth. What’s more, these ideas are like mathematical equations, in that they must be complete in themselves, in the same way that the left and right side of an equation must be absolutely equal (if not identical). Plato’s knowledge, then, relies on Parmenides’ notion of the static perfection of The One, and the self-sufficient completeness into which all individuals are subsumed. Definition is the expression of this completeness. The more complete the definition, the better your understanding.

Aristotle’s idea of knowledge, on the other hand, begins with an inquiry into particulars. A particular object or experience or phenomenon is identified, the nature of that instance is isolated by way of analysis, and then conclusions can be deduced from the general nature to the particular object. These conclusions are self-sufficient and logically necessary, being derived from deductions from generalities derived from observation. The generalities are “first principles”: truths about a thing that are essential to it, in a way that explains its nature, and are common to all individuals like it. Grasping these principles, is therefore, grasping a kind of universal truth. This universal truth is the closest that Aristotle gets to the notion of a Form in the Platonic sense. In his theory of hylomorphism, he actually does call the part of substance that gives an individual it’s “whatness”, the “form”. These forms do indeed define the nature of particular beings, but Aristotle offers no explanation as to what the source of form is, or how it can be discernible absent a unifying element, except to attribute it all to the divine mind.

So, unlike Plato, Aristotle wants to start with what he thinks is the more familiar knowledge — the knowledge of particular experiences — and build a logically sound understanding from that. It’s clear he expects this logical scaffolding is eventually going to lead to a sort of “master principle” that unifies everything. He reaches just such a conclusion in a few specific places — for example, with Prime Matter, and the Prime Mover — but falls short of joining these parts into a unified whole (how are prime matter and the prime mover related? By what mechanism is the prime mover’s will and intellect expressed in the various forms that we see in substantial beings: rocks, people, trees, etc.?). This is the problem with categorical taxonomies. They tend to be irreducible.

Plato presupposes the realm of Ideal Forms, within which the Form of The Good resides, and in which every particular worldly phenomena “participates”. The form of Justice resides there also, and in a hierarchical relationship with The Good. Thus, circumstances on earth which participate in the Form of Justice must also be participants in the Form of The Good. This is why we say that just things are good things. And, unlike Aristotle, Plato makes very few distinctions in the varieties of justice because for him, all instances of justice must unify under the Form of Justice. Thus unified, it is understood. Today, we might think of this as a kind of reductionism. But Plato is not interested in an “explanation” of justice, in either the scientific sense we understand today, or in the taxonomic sense that Aristotle employed. Rather, he sought a holistic apprehension of the Form, similar to what we might today call a ‘beatific vision’. To see the whole, in all its perfected magnificence, as a complete totality, regardless of how baroque its contours, is the pinnacle of wisdom for Plato.

Aristotle, on the other hand, insists that an *account* of all those baroque intricacies are necessary for genuine understanding. In fact, in The Politics, he is convinced that the parts of justice which he does find on examination, are not something that can be unified into a totality in the way that Plato wants it. There are, he insists, at least three ‘kinds’ of particular justice, and at least two kinds of general justice — only one of which resembles Plato’s perfect totality. But this is not a serious problem for Aristotle’s ethics, since justice conforms to virtue, and virtue to happiness (Eudaimonia). Justice, on Aristotle’s account, is the virtue concerned primarily with *the other*, while courage, temperance, and prudence are primarily concerned with *the self*. Being other-regarding means cultivating social habits that maximize the actualization of potentials inherent to the individual, which are then expressed in the aquisition of one’s proper station, relative to others. In aggregate, then, Aristotelian justice effects the same sort of natural order by the freely exercised deliberate desire of individuals, as Plato seeks to impose by authoritarian mandate through rigorous indoctrination and conditioning of citizens.

### Justice and Society

And so, we move from the metaphysical to the moral and political. As is implied above, neither Plato nor Aristotle were democrats in the sense that we think of that term today. Neither was an egalitarian, and Aristotle was a democrat only to the extent that it could be maintained in its least evil form, which he believed would still not last very long. Both philosophers saw hierarchy as an inevitable part of the human experience, and both sought to reconcile that stratification with The One, and to make sense of it in their theories of state.

For Plato, that meant moving all women and children into a common living arrangement, denying them knowledge of parentage, and segregating them into classes of “gold”, “silver”, and “bronze”, according to the quality of their breeding. These various classes of children would be trained for their respective roles as artisans, soldier defenders, and philosopher kings. Each class would be burdened with its own set of social, economic, and political duties and responsibilities, and the degree to which they succeeded in performing these duties would constitute the degree to which they conformed to the universal Form of Justice. The furhter they diverged, the more unjust they would become.

There are a few key features to note, about Plato’s just society. First, it is almost exclusively vertical in character. Only the artisan class is allowed property (and then, only to effect production and trade with other cities). This, Socrates tells us in The Republic, is to insure that the focus is always on the Form of the Good. Owning property encourages private interests and pleasures, which necessarily detract from the common goal of the society, which is to conform to justice. Second, this society is pathologically static. Once this society is assembled and operational (if such a thing were even possible), it could tolerate no modification — not even movement within the classes — without risk of injustice. It is as complete (in the sense of accomplished) an image of the perfect good as is possible on earth, and any innovation or internal motion would constitute a deterioration or corruption. Thus, the Republic would be profoundly brittle, because instead of coping with the reality of change, Plato tries to will change out of existence. So much for Parmenides challenge.

Contrast this with Aristotle, who, though he agrees with Plato that societies that are just are those that are modeled after and oriented toward The Good, deeply disagrees with Plato about how that modeling and orientation is achieved — let alone, what the city will look like in practice, once achieved. Aristotle embraces change in his ethics, arguing explicitly that virtue is an *activity* of the soul, not a final state of being. He argues in the Politics that the telos (“purpose”) of the polis is the establishment of conditions conducive to the good of its members (citizens and non-citizens alike). For Aristotle, this means finding ways to encourage the right proportion of desert, in the particular activities of a society’s members.

Justice, in Aristotle’s “perfected” society, is the totality of virtue actualized by each of its members when serving in their proper roles, for the right reasons, and giving each man what is due to him. Aristotle recognizes more than just the three classes of members that Plato did. He observed a variety of roles in the cities he describes in The Politics, spanning numerous classes, from educators, to laborers, to landowning householders, to slaves, to soldiers and sailors, and so on. This is not that surprising, really. It’s what was already present in existing Greek poleis, and Aristotle begins all of his inquiries by beginning with observation of phenomena. As with his other works, Aristotle in The Politics was trying to build up from what he found, applying the principles he extracted from The Ethics. Plato, by contrast, begins with the definition of the soul, commits the fallacy of composition, and then seeks to radically transform the polis according to that absolute Idea. If material reality resists the effort, then so much the worse for reality.

### Proportion, Equality, and Social Justice

One last word must be said about Aristotle. His idea of incremental improvement, or more precisely, the gradual actualization of virtue in all individuals, as the telos of the state, raises a problem. Given the vast plurality of people, roles, and circumstances in any given polis, it is difficult to fathom what Aristotle could have meant when he said that justice is a “kind of equality”. Clearly, the Aristotelian polis is anything but a utopian equality.

One way to understand what he means, is by recalling that Aristotle does not imply any sort of egalitarianism when he uses the word equality. For him, equality is what is appropriate to the station of the man, and the value imputed in any exchange between men. So, for example, all the men in the same station equally deserve the regard that is due that station – soldiers, for example, deserve the regard and deference of a soldier, regardless of which soldier it is. However, if a solider engages in an exchange with an artisan, the value of the items exchanged need to be identical. In Aristotle’s famous example: three pairs of sandals for a bed. In this way, we could say that market exchanges are not “equalizing” the relationship between soldier and artisan, but rather, the value of good exchanged in the market is set regardless of the station of the individuals engaged in the transaction. A good pair of shoes is a good pair of shoes, regardless of how much merit you deserve, personally. This is a point that wasn’t picked up again, until Adam Smith. But, The point here, is that absolute inequalities are admissible when, in the calculation of the ratio of that inequality, we can resolve to the number 1.

It is this resolution of ratios in the affairs of men, that Aristotle thinks gets us to unity. In modern times, we often depict this as the weight scale with its two trays dangling from chains. But this image is misleading. Because the needle of the weight scale is only resolved, when the trays are level with each other. Aristotle is saying that this image only applies to exchanges of goods between men. Everywhere else, the needle is centered when the trays are not aligned.

Despite the fact that Aristotle’s prescription is for a much more voluntary society than Plato, this realization still makes many people uncomfortable. It means that leaving your station *is an injustice*, in the same way that a workman in Plato’s Republic who took on the pretense of a philosopher-king would be commiting an injustice. But the difference here, is that Aristotle does not presuppose potentialities on account of birth. While he does hold the prejudice of “good birth”, he grounds it in the idea that cultured families will give their sons the grounding they need to actualize virtue, that may or may not remain unrealized in the “lower classes” (to use a modern turn of phrase).

Aristotle never bothers to test whether this “unrealized potential” is there, or not. Like I said, he simply assumes it would not be. But he did test the opposite proposition. Late in life, Aristotle took on the famous Alexander of Macedon, son of Philip II, as a pupil. The relationship between the two is echoed ominously, later, in the relationship between Seneca and Nero. Suffice to say, Alexander was a disappointment to Aristotle (despite being a masterful strategist and general).

It is this realization — that the potential for virtue is not determined by class — that has largely driven 19th and 20th century impulses to democratize education and career opportunities. But we go too far in thinking that this effort will necessarily disolve the presence of class in society. On this point, Aristotle is correct, though Aristotle would not put it in the terms I am about to. The various needs of a society are necessarily going to result the stratification of its members. As we specialize into different kinds of activities, and those activities are assigned different values to the society as a whole, the individuals occupying those endeavors are going to become associated with the values assigned to their products — unless we separate economic value from merit.

Friedrich Hayek tried to point this out in his book, “Law, Legislation, and Liberty”. Thomas Jefferson also hints at this in his appeal to Locke, in the Declaration of Independence, famously declaring that “all men are created equal”. In doing so, however, he inverted eons of social order. Because now, instead of there being tiered classes whose moral worth was fixed by station rather than economic value, there is now only one universal class in which all men a judged to have the same merit, regardless of their economic value. But the inevitable outcome of such a principle, is to deny any man the right to rule. For, without the merit that warrants command over others of lower merit, what justification can there be? All claims to rule begin to look like special pleading fallacies, on this view. Justice would demand that each and every man stand as philosopher-king, guardian, and craftsman of his own kingdom of the self. Clearly, that can’t be right, since the end result would not be unity but the utter atomization of unity.

### Conclusion

I’ve drifted very far from the center of the Parmenidean universe from which this essay began. Or have I? There is a very odd thing about the paradox of The One and The Many. When you stare at it for long enough, its impossible to tell the two apart. I think that’s what’s happened here. In one sense, there is no difference between The One and The Many. Each is just an expression or aspect of the other. In another sense, they are as distinct as right and wrong, or round and square. I am beginning to believe, therefore, that not only is a reconciliation not possible, but that seeking to reconcile the two is a mistake. We can only ever navigate between them, and Plato and Aristotle are personified attempts to do just that; Plato leaning toward The One, Aristotle leaning toward the many, but the both of them never really dispute the need to navigate. Perhaps justice is precisely to be found not in the collapse of the one into the many, or the collapse of the many into the one, but precisely in the gray gap between the two. And perhaps Plato and Aristotle are our guides, leading us this way and that, through the fog, to The Good.

```[Imported from exitingthecave.com on 28 November 2021]```

