---
title: "Technology, Change, and Stasis"
date: 2022-07-19T21:18:37+01:00
tags: ["nostalgia", "technology", "ludditism", "change", "social media", "internet", "information"]
topics: ["philosophy", "sociology", "history", "psychology"]
image: img/edison-at-the-whitehouse-cropped.jpg
description: What Is Lost In What We've Gained?
draft: false
---
## The Internet Is Forever
The attached audio, just below, was recorded in 1894 with an ingenious piece of technology invented in 1878, by Thomas Edison. It was conducted by John Philip Sousa himself, who died in 1932. The recording was digitally transcribed and remastered for distribution on CD, in 2005. I have "ripped" the file from CD, converted it to an internet friendly format, and uploaded it to my server. Now, we are all free to listen to it whenever and wherever we like, with the push of a button.

{{< audio "http://gmgauthier.us-east-1.linodeobjects.com/podcast/audio/supplement-sousa-1894-liberty-bell.ogg" >}}

1894 was 128 years ago. For perspective, the gap between John Locke's "Two Treatises on Government", and the drafting of the Constitution of the US, is just 100 years (1689 - 1789). And the gap between that, and this recording is about another 115 years. Here we all are on the internet in 2022, listening to it as if it was happening right now (barring the audio quality, of course).

Before the 1680s, there was no such thing as a "newspaper". Events were explained to you by way of messengers, or pamphleteers. And, even then, most people didn't read them until the mid-1700's. Before the 1850's, there was no such thing as "photography". If you wanted a portrait or a picture of a place, you hired a painter. Before the 1890's, there was no such thing as "recordings". If you wanted to hear a piece, you hired a band to play it. Before 1915, there was no such thing as a "movie". If you wanted to see a play, you bought tickets and went to the theatre or the puppet show.

Before 1925, there was no such thing as "mass media". If you wanted the news, you bought a newspaper, or asked your neighbour. It was mainly a local affair, and something that effected you personally. What was going on in Paris or London or Moscow or Baghdad or Budapest was for storytellers and novelists, not for every-day consumption (let alone, every hour).

Music, storytelling, pop culture in general, and even knowledge of the world around us, was *particular to a time and a place*, and your experience of it was direct and personal, not absorbed from a distance through a transmission medium (permanently preserved by that medium, as if in amber). How does this change us, personally and socially? What are the consequences of our cleverness? What do we lose in the abundance of synthetic experiences like this? Is hearing this recording actually coming to *know* what a John Phillip Sousa concert was like? Or is it a sort of deceptive story we tell ourselves, through the artificial stimulation of our senses?

## Exploring The Implications
Our relationship to technology is reciprocal. Each new creation eliminates some degree of the time-and-space limitation within which we each exist, but the elimination of that barrier also induces in us an impulse for even greater detachment from the world. In 1894, it would have taken months for you to be able to read this (if you found it at all). Now, as soon as I push the "Publish" button, it's as good as read. And you will treat it with the requisite amount of value as was present in the effort to publish it. Which is to say, with very limited regard. It will always be  here. So, you can always come back to it. And, it is just one of *millions* of blog posts produced every single day.

Everyone says this is a boon. A great benefit. A glorious cornucopia of opportunity. Sure. There's no denying that. But consider the fact that the human being has evolved in, and adapted to, conditions in which his being has been confined by time-and-space barriers that conditioned his psychology, and governed many of his choices. Three hundred years seems like an insurmountable length of time from the place we stand now. But it is a tiny spec of a moment, on an evolutionary scale. What sort of consequence for the human species will there be, in collapsing all of these natural boundaries, and compressing all of these social inputs into one "place" (as it were)?

One of the benefits of being bounded by the limitations of the human body in time and space, is that it affords a natural "default" filter. When sources of news, edification, entertainment, and social narrative are limited to how fast a horse on the pony express can travel, or how much it costs for a ticket to the playhouse which can only afford to put on presentations two or three times per year, then I don't have to work very hard to prioritise what matters in my own life, and incoming influences will only ever have an ephemeral imprint. I may be moved in the moment by some play I've seen, and it may actually alter my attitude or behaviour in some minor way as a consequence, but I am more or less a stable personality in spite of that.

But what about a world in which a worldwide 24-hour media machine is present in the pocket of my blue jeans, and provides a portal to hundreds of thousands of "influencers" constantly vying for my attention -- and the attention of hundreds of thousands more, like me? What are the implications? How does human psychology adapt to that?

The world before 1890 was a world in which the only music you ever heard in your entire life, was the music you and your family members were able to produce on rudimentary instruments in your own home, or by orchestras or bands who come to town maybe two three times per years.

The world of 2022 is a world in which It's hard to imagine a moment in the day when some sort of sound produced by some sort of device *isn't* invading your conscious experience, all the time: pop, rock, classical, ambient, news-talk, podcasts, audiobooks, videos, movies, tv shows, youtubers, and on and on. The interminable din of it all doesn't seem to be putting people off. In fact, they're more attracted to it than ever before in history. We cannot stop listening and watching. It's worse than an addiction.

There's another problem with the use of technology in this space, as well. The record. Before the 1920s, print was basically the only place in which news, ideas, and entertainment weren't completely fluid. Today, however, with modern technologies available to us, there is literally nothing that cannot be a permanent fixture in the culture, somewhere. We have youtube channels that restore and preserve film from the 1880s and 1890s. Others that re-run television shows from the 1950s and 1960s. Others, that archive radio broadcasts over the entire span of radio broadcasting. Others that recycle pop music and music videos from the 1980s, 90s, and 2ks. Others, that recycle movies over the span of the "golden age" of film (roughly 1945 to 1975).

In other words, we have at our fingertips, *all the times, all the time*.

Setting aside the well-worn problem of information overload (which is true, but has been beaten to death), there are other more pressing concerns, in my view. Namely, before these technologies, it was once the case that each generation constructed its own narrative of creation, history, and identity for itself, and some slightly modified version of that would get passed down to the next generation, and the old would pass out of existence. The social world of the man of 1922 and the social world of the man of 1982 are not just different by virtue of the passage of time, but also by the necessity to reconstruct the world anew, each generation.

But now, because of technology that allows us to capture, record, and reproduce nearly all of the sights, sounds, experiences and attitudes of accumulating generations, we have a situation in which three or four generations of competing social narratives remain active constantly, *all the time*. And it seems to be smothering the upcoming generations, who are given a world in which Frank Sinatra and Cardi B, or Ronald Reagan and Donald Trump, or Jimmy Stewart and Jimmy Smits, all have equal footing.

I think one of the symptoms of this problem, can be seen in the fact that modern pop musicians and filmmakers don't seem to be able to construct narratives of their own anymore. Everything is a "reboot", a "prequel", a "reset", or a "remix". They seem only capable of digging up the corpses of past generations, re-animating them, dancing them around like puppets, and dangling the artefacts created by those characters in front of our faces. Star Wars premiered in 1977. By 1997, I was sure that was the last I'd see of Ben Kenobi or Luke Skywalker. But somehow, their skin suits keep re-appearing, year after year after year. And it doesn't stop with star wars. Every single major film franchise of the 1970s and 1980s is constantly recycled. In music, the recycling comes in the form of dismemberment and reassembly. Whenever I'm in a restaurant or mall, I am frequently accosted by the sound of a song I haven't heard since the 1970s. But it's not the song. It's fragments of it, dissected out of the song, and sewn into an electronic beatbox rhythm generator. It's way worse than "creative remix". It's reappropriation for the purpose of monetization, on an industrial scale. All made not only possible, but ridiculously easy, by digital technology.

The end result of all of this seems to be that the latest generations coming online don't have any sense of *themselves* they can hang on to, any clear narrative about their place in the cosmos, their purpose on earth, and the future they want to see. All they seem to know, is what is happening *right now*, and how can I navigate the social landscape in *this moment*, to avoid any penalties. And the cultural accumulations of the past three or four generations made possible by technology, are both an ever-present attic to be picked through for its utility, and an ever-present imposition on the psyche making demands and setting standards no longer possible (or perhaps even desirable) to achieve.

## What Now?
This may come across as some sort of Luddite manifesto. But that is not what I am attempting to advocate by implication, here. Rather, the point is that we have gotten *way ahead* of ourselves, in terms of our own cleverness, and need to take a step back to consider how we are going to cope with the inevitable costs of the benefits we so greatly desire from our cleverness. The question is not "was it worth it?" but rather "how can we be sure that it was worth it?" and "if it's not, presently, then how do we make it worth it going forward (because there's no going back)?". To some, this will sound like a distinction without a difference. But the distinction is significant.

What I want, is more of an opportunity to disengage and be introspective and thoughtful. But, not just myself. The entire civilization. The entire anglo-sphere needs to pause and be silent for 15 minutes. To have a quick look around to see where we are at, and where we are headed. And to ask the questions I have posed in this post. I don't want us to stop changing. That's not even possible. What I want, is for us to be able to ask whether or not the *kind of change* taking place is what *is aimed at the good* for all of us. It seems to me, we have been chasing jangling keys for so long, that we don't know the difference anymore between what is good, and what is novel, amusing, and entertaining. They don't always coincide.
