---
title: "The Euthyphro Expansion Pack"
date: 2016-07-24T15:36:23Z
tags: ["socrates","euthyphro dilemma","platonism"]
topics: ["philosophy"]
image: img/euthyphro.jpg
draft: false
---

## Introduction

I’ve decided to take on the challenge of re-writing the Euthyphro dialogue, [from this Coursera class](https://www.coursera.org/learn/plato/home/welcome), to explore alternative dialectical paths around the dilemma. When I first made this decision, I knew intuitively that if I took it seriously it would actually be a more challenging assignment than simply explicating Plato’s theory of the just soul from The Republic.

Plato’s dialogues are not just sets of step-by-step logical walk-throughs, within which you can simply change premises to arrive at new conclusions. They are Plato’s attempt to reimagine greek dramas – with all the subtext, allegory, and metaphor that comes with any good drama. Plato repeatedly breaks his own “fourth-wall” (at least implicitly) to remind us that he was aware of his project. So, the challenge with this exercise, is to somehow preserve the integrity of the drama, as Plato envisioned it, while exploring the possibility of alternative arguments and conclusions. In my preparation for this assignment, I have discovered that this is not only a more challenging assignment, it is nowhere near as easy as it sounds.

To show you what I mean, I’ve decided to include my stream of consciousness here, in some sort of organized form, in order to give the reader some context into the approach I took in the dialogue itself.

## What the Euthyphro Dilemma Is Not

In modern parlance, The dilemma presented by Socrates to Euthyphro is some sort of challenge to an idea in later Medieval Christian moral philosophy, known as “Divine Command Theory”. To state the problem as simply as possible: It is a monotheistic dilemma in which one horn says that God’s arbitrary will as expressed is the good, and the other horn points to a good that is metaphysically independent of God (to which he refers, when commanding us). The implicit contradiction that arises from this, is that God could not be all-powerful if he was referencing some “higher” objective metaphysical thing that he did not control; but on the other hand, he himself could not be “good”, in any objective sense, if he simply arbitrarily determined what was right and wrong, strictly according to his will. This apparent contradiction is often used as an argument in defense of atheism.

But this is not at all what Socrates and Euthyphro are debating, in the segment in which they engage the dilemma directly. Theirs is not even a debate about what the greek gods command. It’s not about commands at all. It’s a debate about what is, and is not, worthy of love – in particular, worthy of the love of a god (6e – 7a).

Of course, modern monotheists are free to reframe this dilemma all they want, in the formulation of their own theology. But if I am to answer this assignment honestly, I don’t think I can employ any of the common objections to this “modern” version of the dilemma. That would be to answer a different question than that which is posed in this assignment.

## Staying in Character

As I stated initially, I want to maintain the integrity of the narrative, in addition to the logical arguments. It’s important that Euthyphro remains the Euthyphro of this dialogue, and that Socrates remains the Socrates of Euthyphro (and doesn’t suddenly become the Socrates of The Phaedrus, or the Timaeus, for example).

Plato knew what he was doing when he wrote these dialogues. He knew that the narrative structure and the journey of the characters was just as important to his argument, as the arguments themselves. A great example of this, is in The Republic, Book IV and V, where Glaucon, Adeimantus, and Socrates are engaged in a three-way dialogue in search of the meaning of justice. If you read it carefully enough, you’ll find that the three men have been presented to us carefully, so that by the time this exchange takes place (at the home of Cephalus, I believe), they are the dramatic embodiment of the ideal soul, seeking knowledge of “justice”:

- Glaucon is the embodiment of the Timocratic man, the spirited aspect of the soul, and the virtue of Courage
- Adeimantus is the embodiment of the Oligarchic man, the appetitive aspect of the soul, and the virtue of Temperance
- Socrates is the embodiment of the Aristocratic man, the reasoning aspect of the soul, and the virtue of Wisdom

As the three move through their exchange, you can see in their responses to one another, and in the actions of those around them, that the dialectic process is actually elevating each of them. Glaucon is humbled, and assumes albeit briefly, the mantle of the Aristocratic Man. Adeimantus is emboldened, and after a prompt from Polemarchus (449b), challenges Socrates the way Glaucon might have a few pages earlier, becoming the Timocratic man. And even Thrasymachus and Polemarchus are elevated. Polemarchus, the strong-arming Democrat at the beginning of the dialogue, becomes an Oligarch. And, did you notice how in that break when Adeimantus is emboldened to demand that Socrates explain the fate of property and women, Thrasymachus volunteers to include his “vote” in favor of the motion (450a)? He was elevated by the dialectic from a tyrant, to a Democrat, for a time.

The point here, is that to rewrite the Euthyphro, I must necessarily break the dramatic structure that Plato has constructed for a purpose. But why should this destruction be absolute? Couldn’t we limit the damage to something minimal, at least? To my way of thinking, this would require understanding the characters as Plato understood them, and to try to work with them as he would have (at least to the extent that I am competent to do so). To that end, here is the rough sketch of identities, I’ll work with:

EUTHYPHRO:

He is one of a class of men known as the “manteis” (“mantis” in singular). This translates roughly as “seers”. These men served as counselors and advisors to the prominent members of Athenian society. They claimed to have access to divine knowledge, by way of divination powers they inherited at birth. Wikipedia identifies him as an “…Athenian citizen of the Prospalta deme old enough to have appeared multiple times before the Athenian assembly in 399, placing his birth somewhere in the mid-5th century. Euthyphro [according to the eponymous dialogue] had evidently farmed on Naxos, probably as part of the cleruchy established by Pericles in 447 to which his father may have belonged…”

This suggests a man with a great deal of social and political power. It also suggests a man whose own livelihood and power rested on his credibility as a mantis. In other words, a mantis that openly doubted his own powers of divination (access to divine knowledge), would essentially be destroying his own capacity to earn a living, gain any social status, and maintain any power.

SOCRATES:

The question here is not so much what his biography is, but rather, which Socrates is Plato giving us in The Euthyphro? The Socrates of The Republic or the Timaeus, or the Socrates of the Phaedrus or the Symposium, might have given a very different performance than the one that showed up here in the Euthyphro. One could speculate at length about the differences between them. For example, why is Socrates so skeptical of Euthyphro’s divination powers, and yet so enthusiastically credulous of Timaeus’ knowledge of the realm of the heavens? Why is he so tentative about asserting what the gods love and desire here in Euthyphro, and yet so certain of what they love and desire in Republic? These speculations are a topic for another day. But it is enough to show that a fair recasting of the Euthyphro dialogue will avoid the credulous Socrates, and lean toward the skeptical one.

## Moving The Goal Posts

As skeptical as he is, Socrates still volunteers to forego the epistemological question of how it is that Euthyphro knows what the gods love, and don’t love (6a – 6c). One possible reason for this, might be his fear of an even more serious charge of atheism being laid against him, after Meletus’ attack. In any case, he chooses to focus explicitly on the metaphysical question: what is holy (6d)? And, he never returns to the epistemological question in this dialogue.

If this were to become a question in the dialogue, it would have to be Euthyphro that returned them to it. But Euthyphro himself, as I point out above, is absolutely epistemologically committed to his knowledge of the gods, at least, insofar as their existence and the stories about their activities is concerned (6b/6c/6e). And, actually, it’s likely that both men are self-motivated to signal their own fervent belief to each other, for fear of being labelled an atheist. After all, Euthyphro’s own family is threatening to charge him with impiety, too (4d/4e).

So it seems to me, that diverting the dialogue into an epistemological debate about the existence of the gods, or more precisely, our knowing about their existence, would be to radically depart from the basic character motivations in the dialogue. This means, any response that Euthyphro gives to Socrates must presuppose both the existence of, and knowledge of the existence of, the gods and their preferences. Which is probably why Socrates explicitly stipulates to this, himself.

## Third-Party Solutions

I suppose another approach, might be to bring other actors into the dialogue. For example, I could give Protagoras, or Gorgias, or Parmenides a cameo. But then we’d end up with those dialogues, instead of the Euthyphro. And, since I am far less familiar with these characters, than say, Adeimantus or Euthyphro, I’d run a much greater risk of mischaracterizing them, along with getting the arguments wrong.

## Searching For An Entry Point

Dr. Meyer asks us to take up the challenge right at the point that Socrates asks the famous dilemma question, at 10a: “Just consider this question:—Is that which is pious loved by the gods because it is pious, or is it pious because it is loved by the gods?”

But directly preceding this, we miss an opportunity to give Euthyphro a second chance to not to take Socrates’ bait at 9c/9d, where he settles firmly on a definition: “Well, I should say that what all the gods love is pious and, on the other hand, what they all hate is impious.” What if, instead, Euthyphro had simply said, “I’ve already told you Socrates, the only god that matters in this particular case is Zeus, and as such, he is the only god that matters in any case”? But perhaps this is somewhat irrelevant (given point 4).

During the clarifying exchanges, Euthyphro repeatedly affirms his understanding of Socrates’ question, but then, at 10d, he inexplicably seems to switch opinion, and agree with Socrates:

```
Soc:   It is loved by all the gods, is it not, according to what you said?
Euth:  Yes.
Soc:   For this reason: because it is holy, or for some other reason?
Euth:  No, for this reason.
Soc:   It is loved because it is holy, not holy because it is loved?
Euth:  I think so.
```

So, Euthyphro is already vacillating on his assertion in 9d by the time we get to 10d. Shortly after, may be a place where we can believably interject an alternative Euthyphro – at the point where he complains about being confused by Socrates (the Daedalus jest at 11c). Alternatively diverting at 11e would derail Socrates’ exploration of piety as one of the constituent parts of justice, but might also give Euthyphro an opportunity to clarify much of what was confusing Socrates earlier.

Still, without this exploration of piety as a component part of justice, Euthyphro would not have an opportunity to make his assertion at 12e. An assertion that Socrates assents to. So, at this point, we have a basic agreement between them. What’s more, Socrates then goes off on what looks like a hair-splitting adventure around the word “care” (or “attention”, or “service”) at 13a. Here, Socrates equates the gods with pack animals and beasts of burden. Euthyphro could take Socrates to task for that, but here he already begins to diverge with Socrates on the nature of the “caring”.

Perhaps, then, the answer at 13d is a better place to give Euthyphro his redemption. He could respond by explaining that service to the gods is actually very different than that between a servant and a master. But he and Socrates would just end up back at the dead end of labeling what is pious as what is dear to the gods.

## Resignation

So where does that leave us? Near as I can tell, attempting to “improve” on what Plato has already written seems to me to be a fool’s errand. From my reading, these dialogues were never really meant to provide indisputable “answers” to the questions they posed. They were meant to act as demonstrations of the dialectic in action, to show how it can improve the soul — and to give Plato the space he needed to explore his own philosophical commitments. If you read The Laws, or The Parmenides, you’ll find that he actually starts to question all of the bedrock positions he established in dialogues like The Republic.

And it is The Laws that actually gave me the idea for how I could approach the rewrite. The Laws never mentions Socrates. It is an exchange between “an Athenian stranger”, and two other ordinary characters. The stranger is said to resemble Socrates, but many speculate that this stranger is actually Plato himself, attempting to work out a new “compromise” position on politics, that was somewhat less ambitious than what he laid out in The Republic.

This is how one could approach the Euthyphro safely: Instead of attempting to bend Euthyphro or Socrates to my will, I could simply inject myself into the dialogue, as a “traveling Abderan stranger”, who overhears Euthyphro and Socrates debating the idea of piety. But if I joined too soon, I would break the dramatic unity (tripartite dialectic, instead of binary). In fact, I don’t think I’d take this approach if the assignment were to do the same, with The Republic. The reason for this, is the point of view. Euthyphro is in the third-person. So, I could insert myself without having to provide any internal references from Socrates himself. But the Republic is in the first person. This would require Socrates to notice me, to make mention of it, and to actively invite me into the dialog. I don’t think he’d have done that in the context of that dialog.

## Euthyphro Expansion Pack

But what if the stranger appears near the end of the dialogue? At the point where Socrates is at the height of his desperation, and Euthyphro decides to bail out? This would allow us to maintain the dialogue as it is, and in its full context, we could continue the conversation with Socrates almost as if it were a new dialogue. Of course, it’s not going to match the dramatic subtlety or symmetry of Plato, but at least we’re not smashing up an ancient greek masterpiece just to piece it back together with Elmer’s glue. At the very worst, this would be gluing on a pair of easily removable handles.

As such, I think what I’ll do is provide two alternative dialogues. The first, is specific to the assignment, and it will feature a Euthyphro insisting that it is the arbitrary affection of the gods that imbues a thing with piety. The second, will see the dialogue to its conclusion, but interrupt Socrates at the point he is lamenting Euthyphro’s departure, and will re-engage Socrates as if it’s a new dialogue.

And, without further ado, I present to you: the Euthyphro Expansion Pack:

# Dialogue 1: Euthyphro Says No

```
-------- Starting at (9c), for the sake of context: ------------
```

> Soc. But they will be sure to listen if they find that you are a good speaker. [9c] There was a notion that came into my mind while you were speaking; I said to myself: “Well, and what if Euthyphro does prove to me that all the gods regarded the death of the serf as unjust, how do I know anything more of the nature of piety and impiety? for granting that this action may be hateful to the gods, still piety and impiety are not adequately defined by these distinctions, for that which is hateful to the gods has been shown to be also pleasing and dear to them.” And therefore, Euthyphro, I do not ask you to prove this; I will suppose, if you like, [9d] that all the gods condemn and abominate such an action. But I will amend the definition so far as to say that what all the gods hate is impious, and what they love pious or holy; and what some of them love and others hate is both or neither. Shall this be our definition of piety and impiety?

> Euth. Why not, Socrates?

> Soc. Why not! certainly, as far as I am concerned, Euthyphro, there is no reason why not. But whether this admission will greatly assist you in the task of instructing me as you promised, is a matter for you to consider.

> Euth. [9e] Yes, I should say that what all the gods love is pious and holy, and the opposite which they all hate, impious.

> Soc. Ought we to enquire into the truth of this, Euthyphro, or simply to accept the mere statement on our own authority and that of others? What do you say?

> Euth. We should enquire; and I believe that the statement will stand the test of enquiry.

> Soc. We shall know better, my good friend, in a little while. [10a] The point which I should first wish to understand is whether the pious is beloved by the gods because it is pious, or pious because it is beloved of the gods.

> Euth. I do not understand your meaning, Socrates.

> Soc. I will endeavour to explain: we speak of carrying and we speak of being carried, of leading and being led, seeing and being seen. You know that in all such cases there is a difference, and you know also in what the difference lies?

> Euth. I think that I understand.

> Soc. And is not that which is beloved distinct from that which loves?

> Euth. Certainly.

> Soc. [10b] Well; and now tell me, is that which is carried in this state of carrying because it is carried, or for some other reason?

> Euth. No; that is the reason.

> Soc. And the same is true of what is led and of what is seen?

> Euth. True.

> Soc. And a thing is not seen because it is visible, but conversely, visible because it is seen; nor is a thing led because it is in the state of being led, or carried because it is in the state of being carried, but the converse of this. And now I think, Euthyphro, [10c] that my meaning will be intelligible; and my meaning is, that any state of action or passion implies previous action or passion. It does not become because it is becoming, but it is in a state of becoming because it becomes; neither does it undergo because it is in a state of undergoing, but it is in a state of undergoing because it undergoes. Do you agree?

> Euth. Yes.

> Soc. Is not that which is loved in some state either of becoming or undergoing?

> Euth. Yes.

> Soc. And the same holds as in the previous instances; the state of being loved follows the act of being loved, and not the act the state.

> Euth. Certainly.

> Soc. And what do you say of piety, Euthyphro: [10d] is not piety, according to your definition, loved by all the gods?

> Euth. Yes.

> Soc. Because it is pious, or for some other reason?

```
------- DIVERGENCE BEGINS HERE ------------
```

> Euth: As I have stated repeatedly now, what the gods love is what is pious. Their love is what makes a thing a pious thing. Why is this so hard for you to understand?

> Soc: But isn’t this simply giving affection another name?

> Euth: What are you talking about?

> Soc: You’re talking in circles again. You’re saying, that which is loved by the gods is that which is loved by the gods. But you’re calling it piety. Is it love or is it piety? Or, is there any difference?

> Euth: Socrates, my unfortunate friend, we’ve been over this. The gods are mightier than we are. They have powers far beyond that of which we mere mortals are capable. I have offered to tell you of these things, but you refused in favor of this single-minded pursuit of yours. Now, you must listen to me:

> When the gods love a thing, their love covers and surrounds that object, like a vapor or a scent. That emmanation penetrates the object, and through this, it shares in their divine essence with them. It strengthens the object, making it appear admirable in a special way to humankind. This, we call “the pious”.

> Soc: This is remarkable, Euthyphro! I recall that I earlier doubted the stories of war amongst the gods, and still granted the case to you. But this is a tale of unimaginable oddness. How did you come to this knowledge?

> Euth: Come now, Socrates. You know that I am a Mantis. Are you mocking me?

> Soc: By Zeus, no! You are my teacher, and I am desperate for you to help me understand. Otherwise I’ll be left with nothing to defend myself from the wrath of Meletus. I am sorry for this Euthyphro, but I just don’t understand you. If the pious and the beloved are not two different things, then why do we give them two names? Surely, there is something that the gods recognize in a thing. Something that is inspiring their love for it?

> Euth: Now, you are asking for something I am not equipped to offer you. My access to the divine can only tell us what they do and do not love. It cannot tell us why they love what they love, or why hate what they hate. Perhaps you should make a pilgrimage to Delphi.

> Soc: Who is mocking whom, now? In any case, if the gods cannot tell us why they love what they love, and we cannot divine or discern the reasons for their love, what use is it to us?

```
------------------ rejoin briefly, at the end of 13e ------------------
```

> Euth: What use indeed! // Many and fair, Socrates, are the works which they do.

> Soc. Why, my friend, and so are those of a general. But the chief of them is easily told. Would you not say that victory in war is the chief of them?

> Euth. Certainly.

> Soc. Many and fair, too, are the works of the husbandman, if I am not mistaken; but his chief work is the production of food from the earth?

> Euth. Exactly.

> Soc. And of the many and fair things done by the gods, which is the chief or principal one?

> Euth. I have told you already, Socrates, that to learn all these things accurately will be very tiresome. Let me simply say that piety or holiness is learning, how to please the gods in word and deed, by prayers and sacrifices. Such piety, is the salvation of families and states, just as the impious, which is unpleasing to the gods, is their ruin and destruction.

> Soc. I think that you could have answered in much fewer words the chief question which I asked, Euthyphro, if you had chosen. But I see plainly that you are not disposed to instruct me— clearly not: else why, when we reached the point, did you turn, aside? Had you only answered me I should have truly learned of you by this time the— nature of piety. Now, as the asker of a question is necessarily dependent on the answerer, whither he leads— I must follow; and can only ask again, what is the pious, and what is piety? Do you mean that they are a, sort of science of praying and sacrificing?

```
------------ Divergence again, at [14c] ------------
```

> Euth: No, Socrates. You are fatiguing me. I already explained what piety is. What you are describing now, is religious ritual. That is the simple practice of asking and giving to and from the gods. It is not a science, as I explained. It cannot be a science. The things we do in the practice of our religion are pious, because the gods love it. The gods will therefore show us when we are acting with piety, if only we would act.

> Soc: I’m not sure what you mean, Euthyphro. If I cannot discover the meaning of their love, how can I be sure that changing my own behaviors will attract the love of the gods, and thereby insure my piety, before the court? Will you not help me to discover why the gods love what they love?

```
-------- Rejoin, at [15e] --------
```

> Euth: Another time, Socrates; for I am in a hurry, and must go now.

> Soc. Alas! my companion, and will you leave me in despair? I was hoping that you would instruct me in the nature of piety and impiety; and then I might have cleared myself of Meletus and his indictment. I would have told him that I had been enlightened by Euthyphro, and had given up rash innovations and speculations, in which I indulged only through ignorance, and that now I am about to lead a better life.

…And, poor Socrates ends in the same place he began. But what if this dialogue continued, just with another interlocutor?

# Dialogue 2: The Consolation Of A Stranger

```
-------- This dialogue continues the last passage of the original [15e-16a]: -------
```

> Socrates. Alas! my companion, and will you leave me in despair? I was hoping that you would instruct me in the nature of piety and impiety; and then I might have cleared myself of Meletus and his indictment. I would have told him that I had been enlightened by Euthyphro, and had given up rash innovations and speculations, in which I indulged only through ignorance, and that now I am about to lead a better life.

> Abderan Stranger: Socrates, do not despair. I have been listening to your conversation with Euthyphro, and I would be glad to help you on your quest to discover what is piety.

> Socrates: But you are no Euthyphro. He is the one who has this information. Do you know what piety is? Did you already learn it from Euthyphro? Can you tell me?

> Abd: Alas, Socrates, no. I am no Mantis, and I have received no instruction from great Euthyphro. I admit that I do not know what piety is, but as you helped the proud Meno to see, perhaps if we can begin with the ideas you raised with Euthyphro, then we can continue the work together, to discover it.

> Soc: How do you know of my conversation with Meno?

> Abd: Word gets around, in Athens, Socrates. Everyone knows who you are. Your conversations are legendary. Can I give you another example?

> Soc: By all means. Tell me of how my words are reaching the ears of my fellow Athenians!

> Abd: Socrates, you were proposing to Euthyphro earlier that piety may be a part of justice. But this is confusing to me. Did you not already explain to Glaucon and Adeimantus, at the festival of the new Thracian goddess, what is justice?

> Soc: I did, indeed. It was a most beautiful explanation, if I do say so myself. I explained how the soul of man is comprised of three parts: the spirited, the appetitive, and the reasoning, and a balance of these three aspects is derived by educating them by means of the virtues of courage, temperance, and wisdom. And, if we did this consistently, the harmony of the three virtues at play within the soul would produce justice.

> Abd: Right, and now I ask: where does piety now fit into that perfect triangle of virtues? How is piety also produced as a “part” of the justice that is produced?

> Soc: You raise an interesting question, friend. Let’s examine the question together. Is it a part of what is produced, or a part of what produces?

> Abd: What do you mean?

> Soc: Would you say that piety is a virtue that helps to condition some part of the soul, or would you say that piety, in addition to justice, is a result of the three virtues working in harmony?

> Abd: Socrates, I’m not at all sure. If we accept the former, that would break the unity of the three virtues. If we accept the latter, then justice does not appear to be a complete whole, but rather an assemblage of parts.

> Soc: Let us grant the former for the moment, what would be the consequence?

> Abd: The soul would no longer be constituted as a triangle. It would be a square. But the simplest form is the triangle. Shouldn’t the soul follow suit?

> Soc: Yes, this is a problem. But perhaps I have been attacking this from the wrong frame of reference. Tell me, how many perfect solids are there?

> Abd: Well, according to you Socrates, there are five, yes?

> Soc: Yes, that’s quite right, and they are, the Tetrahedron, the Hexahedron, the Octahedron, the Dodecahedron, and the Icosahedron. Let’s start with the first. The Tetrahedron, what shape does it have?

> Abd: It’s a triangle, yes?

> Soc: Not quite. How many sides are needed for this shape?

> Abd: There are four sides to a Tetrahedron.

> Soc: Quite correct. And I see now, the mistake I’ve made with Glaucon and Adeimantus. I should wish to find them and explain it as quickly as possible! My daimon never warned me, but this is so clearly a mistake. I am beside myself.

> Abd: But what is the mistake, Socrates? I don’t understand. What have you discovered?

> Soc: I will draw a triangle in the sand, just here. Do you agree, this is a triangle?

> Abd: Yes, of course, and I can also see how each point can be understood as a point in the just soul, as you’ve so wondrously described it in the past.

> Soc: But this triangle lies flat on the ground. It is like the shadow of this stool, or that tree. It is not the thing itself, but an imperfect image of it. How can I perfect this shape?

> Abd: We should add a side to it. We should raise it out of the sand, so that it stands before us, as a house or tree would. That would give it all the sides of a Tetrahedron, yes?

> Soc: Yes! Exactly. A triangle has three sides. But the perfected form of the triangle has four. By the gods! How could I have missed this? But I see it so clearly now!

> Abd: Socrates, you’re scaring me. Are you alright? What have you discovered? What do you see?

> Soc: Did the storyteller who recounted my trip to Pireaus to you, also tell you of the story of the cave I told to Adeimantus and Glaucon?

> Abd: He did, Socrates, and it was amazing. If you were a poet, we should all be entranced by your tales.

> Soc: Nonsense, I am no poet. It served it’s purpose then, and it will serve it’s purpose again, now. In the allegory, I described men who carried carvings along a walkway, in front of a light. And I explained how the prisoners in the cave could only see the shadows of those objects, dancing on the cave wall in front of them. Do you recall?

> Abd: Yes. Yes, of course.

> Soc: And I described the one who escaped, as traveling to the surface, and finding himself blinded by the light of the bright sun, which he had never seen before, but gradually seeing the true forms of things on the surface, as his eyes adjusted.

> Abd: I remember, Socrates, yes. A very magnificent vision.

> Soc: And do you not see now, how the form of the triangle is like the shadow dancing on the cave wall, and the form of the Tetrahedron is the glimpse we have shared, of the true reality?

> Abd: Absolutely. But what does this have to do with Justice?

> Soc: My anonymous friend, because you have helped me so greatly, I will gladly share what I know with you: In the same way as the triangle is the shadow of the Tetrahedron, the soul I have constructed, and the image of justice within it, is a mere shadow! The true soul, and the image of true justice within it, has four aspects, not three!

> In addition to Spirit, Appetite, and Reasoning, there is a fourth aspect. The aspect that is shared with the gods. The aspect that looks upward, not in the way that the Reasoning does, but toward the gods. The virtue that tempers it is Reverence or Piety. In the same way that Wisdom tempers the Reasoning aspect. The vice that corrupts this aspect is Vaingloriousness or Impiety, in the same way that Pride corrupts the Reasoning aspect. It is the third horse harnessed to the chariot of the soul. We shall call this aspect “Faith”.

> Abd: Socrates, I haven’t the breath to respond. This vision you have produced is overwhelming.

> Soc: Well, stranger, we’ve no time to lose. It is late, and I must make my way to Glaucon’s at once. Will you accompany me?

> Abd: Why, I would follow you anywhere! Lead on, teacher.

> Soc: By the way, what did you say your name was?

## Sources

Perseus Digital Library

Friesian.com

The Seer In Ancient Greece, Michael Flower

The Augustine Collective

The Play Of Characters In Plato’s Dialogues, Ruby Blondell

Wikipedia

Internet Encyclopedia Of Philosophy

Stanford Encyclopedia Of Philosophy

University of Washington

Plato, Socrates, And The Dialogues, Professor Michael Sugrue

Mathpages.com

```[Imported from exitingthecave.com on 28 November 2021```
